@@ -7,13 +7,13 @@ mainPDF = MainPDF()
 
 
 # 给pdf加水印-无参数
-@except_dec()
+# @except_dec()
 def add_watermark() -> None:
     mainPDF.add_watermark()
 
 
 # 给pdf加水印-有参数
-@except_dec()
+# @except_dec()
 def add_watermark_by_parameters(pdf_file, mark_str, output_file_name='添加了水印的文件.pdf') -> None:
     """
     必填参数：
@@ -26,40 +26,40 @@ def add_watermark_by_parameters(pdf_file, mark_str, output_file_name='添加了
 
 
 # txt转pdf
-@except_dec()
+# @except_dec()
 def txt2pdf(path: str, res_pdf='txt2pdf.pdf'):
     mainPDF.file2pdf(path, res_pdf)
 
 
 # PDF加密
-@except_dec()
+# @except_dec()
 def encrypt4pdf(path, password, res_pdf='encrypt.pdf'):
     mainPDF.encrypt4pdf(path, password, res_pdf)
 
 
 # PDF解密
-@except_dec()
+# @except_dec()
 def decrypt4pdf(path, password, res_pdf='decrypt.pdf'):
     mainPDF.decrypt4pdf(path, password, res_pdf)
 
 
 # 合并pdf
-@except_dec()
+# @except_dec()
 def merge2pdf(one_by_one, output):
     mainPDF.merge2pdf(one_by_one, output)
 
 
 # todo：输入文件路径
-@except_dec()
+# @except_dec()
 def pdf2docx(file_path, output_path='.'):
     mainPDF.pdf2docx(file_path, output_path)
 
 
-@except_dec()
+# @except_dec()
 def pdf2imgs(pdf_path, out_dir):
     mainPDF.pdf2imgs(pdf_path, out_dir)
 
 
-@except_dec()
+# @except_dec()
 def add_img_water(pdf_file_in, pdf_file_mark, pdf_file_out):
     mainPDF.add_img_watermark(pdf_file_in, pdf_file_mark, pdf_file_out)
